@@ -1,21 +1,23 @@
 """`/api/v4/key/distribution/nodes` endpoint."""
 
-from typing import Optional
+from typing import Annotated
 
 from aio_taginfo.api.v4 import PngResponse
 from aio_taginfo.api.v4._internal import api_get_png, api_params
 
 from aiohttp import ClientSession
-from pydantic import Field, constr
+from pydantic import Field, StringConstraints
 from pydantic.dataclasses import dataclass
 
 
-@dataclass
+@dataclass(kw_only=True)
 class _Params:
-    key: constr(min_length=1, strip_whitespace=True, strict=True) = Field(repr=True, frozen=True)
+    key: Annotated[str, StringConstraints(min_length=1, strip_whitespace=True, strict=True)] = (
+        Field(repr=True, frozen=True)
+    )
 
 
-async def call(key: str, session: Optional[ClientSession] = None) -> PngResponse:
+async def call(key: str, session: ClientSession | None = None) -> PngResponse:
     """
     Get map with distribution of this key in the database (nodes only).
 
